@@ -483,7 +483,7 @@ def plot_simulated_lap_times(lap_times_df):
     # set labels and title
     ax.set_xlabel("Lap Number")
     ax.set_ylabel("Lap Time (s)")
-    #plt.suptitle(f"The driver's Simulated Lap Times at {lap_times_df.Race[0]}")
+    plt.suptitle(f"The driver's Simulated Lap Times at {lap_times_df.Race[0]}")
     plt.grid(color = "w", which = 'major', axis = 'both')
     sns.despine(left = True, bottom = True)
     # get the plot's legend
